import { Component, OnDestroy, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router } from '@angular/router';

@Component({
  selector: 'app-home',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']
})
export class HomeComponent implements OnInit, OnDestroy {
  currentSlide = 0;
  slideInterval: any;

  bannerSlides = [
    {
      icon: '🎨',
      title: '春季新品发布',
      subtitle: '个性化设计，独一无二',
      background: 'linear-gradient(135deg, #667eea 0%, #764ba2 100%)'
    },
    {
      icon: '✨',
      title: 'AI智能搭配',
      subtitle: '科技赋能时尚创意',
      background: 'linear-gradient(135deg, #ff9a9e 0%, #fecfef 100%)'
    },
    {
      icon: '🏆',
      title: '设计大赛进行中',
      subtitle: '万元奖金等你来拿',
      background: 'linear-gradient(135deg, #a8edea 0%, #fed6e3 100%)'
    }
  ];

  popularWorks = [
    {
      image: '🌿',
      title: '森系小清新',
      likes: '2.3k',
      comments: '186',
      gradient: 'linear-gradient(45deg, #a8edea 0%, #fed6e3 100%)'
    },
    {
      image: '🎭',
      title: '复古摩登',
      likes: '1.8k',
      comments: '142',
      gradient: 'linear-gradient(45deg, #ffd89b 0%, #19547b 100%)'
    },
    {
      image: '🚀',
      title: '未来科技',
      likes: '3.1k',
      comments: '256',
      gradient: 'linear-gradient(45deg, #667eea 0%, #764ba2 100%)'
    },
    {
      image: '🏛️',
      title: '简约现代',
      likes: '1.5k',
      comments: '98',
      gradient: 'linear-gradient(45deg, #ff9a9e 0%, #fecfef 100%)'
    }
  ];

  constructor(private router: Router) {}

  ngOnInit(): void {
    this.startSlideshow();
  }

  ngOnDestroy(): void {
    if (this.slideInterval) {
      clearInterval(this.slideInterval);
    }
  }

  startSlideshow(): void {
    this.slideInterval = setInterval(() => {
      this.nextSlide();
    }, 4000);
  }

  nextSlide(): void {
    this.currentSlide = (this.currentSlide + 1) % this.bannerSlides.length;
  }

  goToSlide(index: number): void {
    this.currentSlide = index;
  }

  bannerClick(index: number): void {
    if (index === 1) {
      this.router.navigate(['/ai-chat']);
    } else if (index === 2) {
      this.router.navigate(['/community']);
    } else {
      console.log(`Banner ${index + 1} clicked`);
    }
  }

  navigateToDesignCenter(): void {
    this.router.navigate(['/design']);
  }

  showWorkDetail(work: any): void {
    // Implement navigation to work detail page
    console.log('Show work detail for:', work.title);
  }

  openAIChat(type: string): void {
    // Implement AI chat logic
    console.log(`Open AI chat with type: ${type}`);
    this.router.navigate(['/ai-chat']);
  }
} 