import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router } from '@angular/router';

@Component({
  selector: 'app-profile',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './profile.component.html',
  styleUrls: ['./profile.component.scss']
})
export class ProfileComponent implements OnInit {

  isSettingsModalVisible = false;
  isDraftsModalVisible = false;
  isMyWorksModalVisible = false;
  activeWorksTab = 'published';

  constructor(private router: Router) { }

  ngOnInit(): void {
  }

  showNotification(title: string, message?: string): void {
      // For now, we use a simple alert. A dedicated notification service would be better.
      alert(`${title}${message ? ': ' + message : ''}`);
  }

  // Main menu actions
  showDrafts(): void {
    this.isDraftsModalVisible = true;
  }

  showMyWorks(): void {
    this.isMyWorksModalVisible = true;
  }

  showTryOnHistory(): void {
    this.showNotification('试穿历史', '此功能正在开发中。');
  }

  showOrders(): void {
    this.showNotification('订单管理', '此功能正在开发中。');
  }

  showCollections(): void {
    this.showNotification('收藏夹', '此功能正在开发中。');
  }

  showFollowers(): void {
    this.showNotification('粉丝管理', '此功能正在开发中。');
  }

  showSettings(): void {
    this.isSettingsModalVisible = true;
  }

  // Settings Modal
  closeSettingsModal(): void {
    this.isSettingsModalVisible = false;
  }

  changeAvatar(): void {
    this.showNotification('更换头像', '此功能正在开发中。');
  }

  changePassword(): void {
    this.showNotification('修改密码', '此功能正在开发中。');
  }

  bindPhone(): void {
    this.showNotification('绑定手机', '此功能正在开发中。');
  }

  bindEmail(): void {
    this.showNotification('绑定邮箱', '此功能正在开发中。');
  }

  showAbout(): void {
    this.showNotification('关于 FashionCraft', 'v1.0.0 - 让创意穿在身上');
  }

  clearCache(): void {
    if (confirm('确定要清除缓存吗？')) {
      this.showNotification('缓存已清除');
    }
  }

  feedback(): void {
    this.showNotification('意见反馈', '感谢您的反馈！');
  }

  saveSettings(): void {
    this.showNotification('设置已保存');
    this.closeSettingsModal();
  }

  confirmLogout(): void {
    if (confirm('您确定要退出登录吗？')) {
      this.showNotification('退出登录成功');
      // Here you would typically call an authentication service to log out
      // and then navigate to the login page.
      this.closeSettingsModal();
      this.router.navigate(['/auth']);
    }
  }

  // Drafts Modal
  closeDraftsModal(): void {
    this.isDraftsModalVisible = false;
  }

  editDraft(id: number): void {
    this.showNotification(`编辑草稿 ${id}`);
  }

  deleteDraft(id: number): void {
    if (confirm(`确定要删除草稿 ${id} 吗？`)) {
      this.showNotification(`草稿 ${id} 已删除`);
    }
  }

  openUploadModal(): void {
      this.showNotification('打开上传窗口', '此功能正在开发中。');
  }

  // My Works Modal
  closeMyWorksModal(): void {
    this.isMyWorksModalVisible = false;
  }

  switchWorksTab(tab: string, event: MouseEvent): void {
    this.activeWorksTab = tab;
    const tabContainer = (event.target as HTMLElement).parentElement;
    if (tabContainer) {
        Array.from(tabContainer.children).forEach(child => child.classList.remove('active'));
        (event.target as HTMLElement).classList.add('active');
    }
  }

  editWork(id: number): void {
    this.showNotification(`编辑作品 ${id}`);
  }

  deleteWork(id: number): void {
    if (confirm(`确定要删除作品 ${id} 吗？`)) {
      this.showNotification(`作品 ${id} 已删除`);
    }
  }
} 