import { Component, OnInit, OnDestroy } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router, NavigationEnd } from '@angular/router';
import { Subject, takeUntil, filter } from 'rxjs';

@Component({
  selector: 'app-bottom-navigation',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './bottom-navigation.component.html',
  styleUrl: './bottom-navigation.component.scss'
})
export class BottomNavigationComponent implements OnInit, OnDestroy {
  currentPage: string = 'home';
  private destroy$ = new Subject<void>();

  constructor(private router: Router) {}

  ngOnInit(): void {
    // 初始化当前页面状态
    this.updateCurrentPage();
    
    // 订阅路由导航结束事件
    this.router.events
      .pipe(
        filter(event => event instanceof NavigationEnd),
        takeUntil(this.destroy$)
      )
      .subscribe(() => {
        this.updateCurrentPage();
      });
  }

  ngOnDestroy(): void {
    this.destroy$.next();
    this.destroy$.complete();
  }

  onNavigate(page: string): void {
    console.log('点击导航按钮:', page);
    
    let route: string;
    
    switch (page) {
      case 'home':
        route = '/home';
        break;
      case 'design':
        route = '/design';
        break;
      case 'fitting':
        route = '/fitting';
        break;
      case 'community':
        route = '/community';
        break;
      case 'profile':
        route = '/profile';
        break;
      default:
        route = '/home';
    }
    
    console.log('准备跳转到:', route);
    console.log('当前页面:', this.currentPage);
    
    // 如果目标页面与当前页面相同，不执行跳转
    if (this.currentPage === page) {
      console.log('目标页面与当前页面相同，跳过跳转');
      return;
    }
    
    this.router.navigate([route]).then(success => {
      if (success) {
        console.log('路由跳转成功到:', route);
      } else {
        console.error('路由跳转失败到:', route);
      }
    }).catch(error => {
      console.error('路由跳转错误:', error);
    });
  }

  private updateCurrentPage(): void {
    const currentUrl = this.router.url;
    console.log('当前URL:', currentUrl);
    
    if (currentUrl.includes('/home')) {
      this.currentPage = 'home';
    } else if (currentUrl.includes('/design')) {
      this.currentPage = 'design';
    } else if (currentUrl.includes('/fitting')) {
      this.currentPage = 'fitting';
    } else if (currentUrl.includes('/community')) {
      this.currentPage = 'community';
    } else if (currentUrl.includes('/profile')) {
      this.currentPage = 'profile';
    } else {
      this.currentPage = 'home';
    }
    
    console.log('更新当前页面状态为:', this.currentPage);
  }
} 