import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
// import { HttpClient } from '@angular/common/http';
import { User, LoginRequest, RegisterRequest, AuthResponse } from '../models/user.model';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  // private readonly API_BASE_URL = 'https://api.fashioncraft.com/api';
  private currentUserSubject = new BehaviorSubject<User | null>(null);
  private isAuthenticatedSubject = new BehaviorSubject<boolean>(false);

  public user$ = this.currentUserSubject.asObservable();
  public isAuthenticated$ = this.isAuthenticatedSubject.asObservable();

  constructor(/*private http: HttpClient*/) {
    this.initializeAuth();
  }

  private initializeAuth(): void {
    const token = localStorage.getItem('fashioncraft_token');
    const userStr = localStorage.getItem('fashioncraft_user');
    
    if (token && userStr) {
      try {
        const user = JSON.parse(userStr);
        this.setUser(user);
      } catch (error) {
        console.error('解析用户数据失败:', error);
        this.clearAuthData();
      }
    }
  }

  async login(credentials: LoginRequest): Promise<User> {
    // try {
    //   const response = await this.http.post<AuthResponse>(`${this.API_BASE_URL}/auth/login`, credentials).toPromise();
      
    //   if (response && response.code === 200) {
    //     this.setAuthData(response.data.user, response.data.token);
    //     return response.data.user;
    //   } else {
    //     throw new Error(response?.message || '登录失败');
    //   }
    // } catch (error: any) {
    //   // 如果服务器不可用，使用模拟登录
    //   if (error.status === 0 || error.status >= 500) {
    //     return this.mockLogin(credentials);
    //   }
    //   throw error;
    // }
    return this.mockLogin(credentials);
  }

  async register(userData: RegisterRequest): Promise<User> {
    // try {
    //   const response = await this.http.post<AuthResponse>(`${this.API_BASE_URL}/auth/register`, userData).toPromise();
      
    //   if (response && response.code === 200) {
    //     this.setAuthData(response.data.user, response.data.token);
    //     return response.data.user;
    //   } else {
    //     throw new Error(response?.message || '注册失败');
    //   }
    // } catch (error: any) {
    //   // 如果服务器不可用，使用模拟注册
    //   if (error.status === 0 || error.status >= 500) {
    //     return this.mockRegister(userData);
    //   }
    //   throw error;
    // }
    return this.mockRegister(userData);
  }

  private mockLogin(credentials: LoginRequest): Promise<User> {
    return new Promise((resolve) => {
      setTimeout(() => {
        const mockUser: User = {
          id: '1',
          username: credentials.username,
          email: credentials.username.includes('@') ? credentials.username : 'user@example.com',
          nickname: '时尚设计师',
          avatar: '',
          bio: '热爱时尚设计，专注于创新与美学的完美结合',
          location: '上海',
          createdAt: new Date(),
          updatedAt: new Date()
        };
        
        this.setAuthData(mockUser, 'mock-token-' + Date.now());
        resolve(mockUser);
      }, 1000);
    });
  }

  private mockRegister(userData: RegisterRequest): Promise<User> {
    return new Promise((resolve) => {
      setTimeout(() => {
        const mockUser: User = {
          id: '1',
          username: userData.username,
          email: userData.email,
          nickname: userData.username,
          avatar: '',
          bio: '',
          location: '',
          createdAt: new Date(),
          updatedAt: new Date()
        };
        
        this.setAuthData(mockUser, 'mock-token-' + Date.now());
        resolve(mockUser);
      }, 1000);
    });
  }

  async logout(): Promise<void> {
    // try {
    //   const token = localStorage.getItem('fashioncraft_token');
    //   if (token) {
    //     await this.http.post(`${this.API_BASE_URL}/auth/logout`, {}, {
    //       headers: { Authorization: `Bearer ${token}` }
    //     }).toPromise();
    //   }
    // } catch (error) {
    //   console.error('退出登录失败:', error);
    // } finally {
    //   this.clearAuthData();
    // }
    this.clearAuthData();
  }

  private setAuthData(user: User, token: string): void {
    localStorage.setItem('fashioncraft_token', token);
    localStorage.setItem('fashioncraft_user', JSON.stringify(user));
    this.setUser(user);
  }

  private clearAuthData(): void {
    localStorage.removeItem('fashioncraft_token');
    localStorage.removeItem('fashioncraft_user');
    this.setUser(null);
  }

  setUser(user: User | null): void {
    this.currentUserSubject.next(user);
    this.isAuthenticatedSubject.next(!!user);
  }

  get user(): User | null {
    return this.currentUserSubject.value;
  }

  get isAuthenticated(): boolean {
    return this.isAuthenticatedSubject.value;
  }

  getToken(): string | null {
    return localStorage.getItem('fashioncraft_token');
  }
} 