import { Injectable } from '@angular/core';
// import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable, of } from 'rxjs';
// import { catchError, map } from 'rxjs/operators';
// @ts-ignore
// import { environment } from '../../environments/environment';
import { Work } from '../models/work.model';
import { AuthService } from './auth.service';
import { NotificationService } from './notification.service';

const MOCK_WORKS: Work[] = [
  {
    id: '1',
    title: '复古风格连衣裙',
    description: '一款融合了20世纪50年代元素的现代连衣裙设计。',
    imageUrl: 'assets/images/works/retro-dress.png',
    images: ['assets/images/works/retro-dress.png'],
    author: { id: '1', nickname: '时尚设计师', avatar: 'assets/images/avatars/designer.png' },
    likes: 152,
    comments: 34,
    views: 2300,
    tags: ['连衣裙', '复古', '春夏'],
    createdAt: new Date('2023-04-10T14:48:00'),
    updatedAt: new Date('2023-04-11T09:22:00'),
    gradient: 'linear-gradient(to top, #a18cd1 0%, #fbc2eb 100%)',
    isLiked: false,
  },
  {
    id: '2',
    title: '都市通勤夹克',
    description: '简约而功能性强的设计，适合现代都市女性的日常穿着。',
    imageUrl: 'assets/images/works/urban-jacket.png',
    images: ['assets/images/works/urban-jacket.png'],
    author: { id: '2', nickname: '都市先锋', avatar: 'assets/images/avatars/pioneer.png' },
    likes: 230,
    comments: 58,
    views: 4500,
    tags: ['夹克', '通勤', '秋冬'],
    createdAt: new Date('2023-05-01T11:20:00'),
    updatedAt: new Date('2023-05-01T11:20:00'),
    gradient: 'linear-gradient(to top, #48c6ef 0%, #6f86d6 100%)',
    isLiked: true,
  },
  // 在这里可以添加更多的模拟作品
];

function createMockResponse(data: Work | Work[]): Observable<WorkResponse> {
  return of({ code: 200, message: '操作成功', data });
}

export interface WorkResponse {
  code: number;
  message: string;
  data: Work | Work[];
}

@Injectable({
  providedIn: 'root'
})
export class CommunityService {
  // private apiUrl = environment.apiUrl;

  constructor(
    // private http: HttpClient,
    private authService: AuthService,
    private notificationService: NotificationService
  ) {}

  // 获取作品详情
  getWorkDetail(workId: string): Observable<WorkResponse> {
    const work = MOCK_WORKS.find(w => w.id === workId) || MOCK_WORKS[0];
    return createMockResponse(work);
  }

  // 获取热门作品
  getPopularWorks(): Observable<WorkResponse> {
    const popularWorks = [...MOCK_WORKS].sort((a, b) => b.likes - a.likes);
    return createMockResponse(popularWorks);
  }

  // 获取最新作品
  getLatestWorks(): Observable<WorkResponse> {
    const latestWorks = [...MOCK_WORKS].sort((a, b) => b.createdAt!.getTime() - a.createdAt!.getTime());
    return createMockResponse(latestWorks);
  }

  // 获取用户作品
  getUserWorks(userId?: string): Observable<WorkResponse> {
    const id = userId || this.authService.user?.id;
    if (!id) {
      return of({ code: 401, message: '未登录', data: [] });
    }
    const userWorks = MOCK_WORKS.filter(w => w.author.id === id);
    return createMockResponse(userWorks);
  }

  // 发布作品
  publishWork(work: Work): Observable<WorkResponse> {
    const newWork: Work = {
      ...work,
      id: String(Date.now()),
      author: this.authService.user || { id: 'mock-user', nickname: '模拟用户' },
      likes: 0,
      comments: 0,
      createdAt: new Date(),
      updatedAt: new Date(),
    };
    MOCK_WORKS.unshift(newWork);
    return createMockResponse(newWork);
  }

  // 获取所有作品
  getAllWorks(): Observable<WorkResponse> {
    return createMockResponse(MOCK_WORKS);
  }

  // 点赞作品
  likeWork(workId: string): Observable<{code: number, message: string}> {
    const work = MOCK_WORKS.find(w => w.id === workId);
    if (work) {
      work.isLiked = !work.isLiked;
      work.likes += work.isLiked ? 1 : -1;
    }
    return of({ code: 200, message: '操作成功' });
  }

  // 错误处理
  // private handleError<T>(operation = 'operation') {
  //   return (error: any): Observable<any> => {
  //     console.error(`${operation} 失败:`, error);
  //     this.notificationService.showError('操作失败', error.message || '请稍后再试');
  //     return of({ code: error.status || 500, message: error.message || '服务器错误', data: null });
  //   };
  // }
} 